# {Locations, Age, Follower look-alikes, Platforms, ...} -used as Twitter Ad Target Criterias

## intro

Here's we're going to first find out all those possible ad target categories, used for targeting ads. Then for each of them, we'll figure out top 30 most used target values, which are to be plotted as horizontal bar plot.

## example

Here're some example plots from some ad target criterias.

### Locations

![twitterAdTargetCriteriasUsedInLocationsForAnjan_Roy](../plots/twitterAdTargetCriteriasUsedInLocationsForAnjan_Roy.png)

### Gender

![twitterAdTargetCriteriasUsedInGenderForAnjan_Roy](../plots/twitterAdTargetCriteriasUsedInGenderForAnjan_Roy.png)

### Age

![twitterAdTargetCriteriasUsedInAgeForAnjan_Roy](../plots/twitterAdTargetCriteriasUsedInAgeForAnjan_Roy.png)

### Interests

![twitterAdTargetCriteriasUsedInInterestsForAnjan_Roy](../plots/twitterAdTargetCriteriasUsedInInterestsForAnjan_Roy.png)

### Languages

![twitterAdTargetCriteriasUsedInLanguagesForAnjan_Roy](../plots/twitterAdTargetCriteriasUsedInLanguagesForAnjan_Roy.png)

### Platforms

![twitterAdTargetCriteriasUsedInPlatformsForAnjan_Roy](../plots/twitterAdTargetCriteriasUsedInPlatformsForAnjan_Roy.png)

### Follower look-alikes

![twitterAdTargetCriteriasUsedInFollower_look-alikesForAnjan_Roy](../plots/twitterAdTargetCriteriasUsedInFollower_look-alikesForAnjan_Roy.png)

More can be found [here](https://github.com/itzmeanjan/twiz/tree/master/plots)
